#
# spec file for package python-gwdatafind
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1

Name:           python-gwdatafind
Version:        1.2.0
Release:        2.1
License:        GPL-3.0-only
Summary:        Client library for the LIGO Data Replicator (LDR) service
URL:            https://gwdatafind.readthedocs.io/
Source:         https://files.pythonhosted.org/packages/source/g/gwdatafind/gwdatafind-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module ligo-segments}
BuildRequires:  %{python_module igwn-auth-utils}
BuildRequires:  %{python_module pytest >= 2.8.0}
BuildRequires:  %{python_module requests-mock}
# /SECTION
BuildRequires:  fdupes
Requires:       python-igwn-auth-utils
Requires:       python-ligo-segments
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun):update-alternatives

%python_subpackages

%description
The client library for the LIGO Data Replicator (LDR) service.

The DataFind service allows users to query for the location of
Gravitational-Wave Frame (GWF) files containing data from the current
gravitational-wave detectors

%prep
%setup -q -n gwdatafind-%{version}
sed -i 's/--color=yes//' pyproject.toml

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/gw_data_find

%check
%pytest -k 'not (test_find_urls or test_find_frame_urls or test_postprocess_cache_gaps)'

%post
%python_install_alternative gw_data_find

%postun
%python_uninstall_alternative gw_data_find

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/gw_data_find
%{python_sitelib}/gwdatafind
%{python_sitelib}/gwdatafind-%{version}*-info

%changelog
* Fri Dec  6 2024 Atri Bhattacharya <badshah400@gmail.com>
- Fix builds by avoiding tests not ready for updated ligo-segments
  yet.
* Thu Dec 28 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.0
  * Add support for non-GWF file extensions (!83)
  * Use argparse-manpage for manual generation (!80)
  * Update references to gwosc.org (!87)
  * Support multi-character site IDs (!91)
  * Add support for Python 3.11 and 3.12 (!93)
- Update dependencies: (Build)Requires: python-igwn-auth-utils
  instead of python-igwn-auth-utils-requests.
* Fri Jan 13 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.1.3:
  * No changelog.
- Update python-igwn-auth-utils version requirement in keeping
  with upstream.
* Sun Jul  3 2022 Ben Greiner <code@bnavigator.de>
- Update to version 1.1.1
  * [!72] fix critical issue with deprecated HTTPConnection
    interface
- Release 1.1.0
  * [!38] the gwdatafind.http module and the classes therein have
    been deprecated and replaced by the functional calls available
    from the top-level gwdatafind module; gwdatafind.http will be
    removed in GWDataFind 2.0.0.
  * [!50] support for Python 3.5 has been dropped
  * [!38] the library was refactored to use
    igwn_auth_utils.requests for all HTTP access; this provides
    support for authorized queries using SciTokens
* Mon Mar 21 2022 pgajdos@suse.com
- actually does not require python-mock for build
* Tue Feb  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.5:
  * Remove support for Python 2 [!32].
  * Add support for Python 3.10 [!37].
  * Rename `LIGO_DATAFIND_SERVER` -> `GWDATAFIND_SERVER` [!29].
  * Restructure binary packages for Debian and RHEL [!27,!35,!42].
* Fri Jan 22 2021 Atri Bhattacharya <badshah400@gmail.com>
- Fix binary installation for multi-version python.
* Mon Nov  2 2020 Atri Bhattacharya <badshah400@gmail.com>
- Use `%%pytest` to run tests and drop python-pytest-runner from
  BuildRequires.
* Thu Apr 23 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
